@@ -7,11 +7,15 @@ from djangorestframework.views import ListOrCreateModelView, InstanceModelView
 from djangorestframework.mixins import PaginatorMixin
 from djangorestframework.status import HTTP_400_BAD_REQUEST
 from djangorestframework.response import ErrorResponse
-from djangorestframework import renderers
-
-from forms import MovePageForm, MovePageContentItemForm
+from djangorestframework.renderers import JSONRenderer, DocumentingHTMLRenderer
 
 from fiber.models import Page, PageContentItem
+from .forms import MovePageForm, MovePageContentItemForm
+from fiber.app_settings import API_RENDER_HTML
+
+API_RENDERERS = (JSONRenderer, )
+if API_RENDER_HTML:
+    API_RENDERERS = (JSONRenderer, DocumentingHTMLRenderer)
 
 
 class ApiRoot(View):
@@ -20,7 +24,7 @@ class ApiRoot(View):
     """
 
     permissions = (IsAuthenticated, )
-    renderers = (renderers.JSONRenderer, )
+    renderers = API_RENDERERS
 
     def get(self, request):
         return [
@@ -35,7 +39,7 @@ class ApiRoot(View):
 class ListView(ListOrCreateModelView):
 
     permissions = (IsAuthenticated, )
-    renderers = (renderers.JSONRenderer, )
+    renderers = API_RENDERERS
 
 
 class TreeListView(View):
@@ -107,13 +111,13 @@ class ImageListView(PaginatedListView):
 class InstanceView(InstanceModelView):
 
     permissions = (IsAuthenticated, )
-    renderers = (renderers.JSONRenderer, )
+    renderers = API_RENDERERS
 
 
 class MovePageView(View):
 
     permissions = (IsAuthenticated, )
-    renderers = (renderers.JSONRenderer, )
+    renderers = API_RENDERERS
 
     form = MovePageForm
 
@@ -130,7 +134,7 @@ class MovePageView(View):
 class MovePageContentItemView(View):
 
     permissions = (IsAuthenticated, )
-    renderers = (renderers.JSONRenderer, )
+    renderers = API_RENDERERS
 
     form = MovePageContentItemForm
 
