@@ -780,7 +780,8 @@ Fiber.ImageSelectDialog = BaseFileSelectDialog.extend({
 
 		function thumbnail_formatter(value, row_data) {
 			// insert the url that ckeditor looks for. Use HTML5 data attribute instead?
-			return '<span style="display: none;">' + row_data.image_url + '</span>' + '<img src="' + row_data.image_url + '" title="' + row_data.title + '"/>';
+			// TODO: use image checksum for cache busting?
+			return '<span style="display: none;">' + row_data.image_url + '</span>' + '<img src="' + row_data.image_url + '?_c=' + encodeURIComponent(row_data.url) + '" title="' + row_data.title + '"/>';
 		}
 
 		this.select_grid.simple_datagrid({
